@@ -25,7 +25,7 @@
 #include <string.h>
 
 /* Version information */
-#define SABYENC_VERSION "3.3.5"
+#define SABYENC_VERSION "3.3.6"
 
 /* Do we CRC check? */
 #define CRC_CHECK   0
@@ -43,6 +43,10 @@
 #define SPACE       0x20
 #define DOT         0x2e
 
+/* 10MB should be enough for any article,
+   as 1MB is the common maximum */
+#define MAX_RESERVED_BYTES     10111000
+
 /* Customized types */
 typedef unsigned long long uLong;
 typedef unsigned int uInt;
